# QuantumVITAS (Legacy Placeholder)

This is a placeholder package to reserve the `quantumvitas` name on PyPI.  
The original QuantumVITAS GUI project has been superseded by **QMatSuite**.

This package contains no functional code.
